@@ -3,6 +3,7 @@
 from datetime import datetime
 
 from ..interfaces import (
+    ClientType,
     IAccessToken,
     IAuthorizationCode,
     IClient,
@@ -29,6 +30,12 @@ class Client(IClient):
     def get_id(self):
         return self.id
 
+    def get_redirect_uri(self):
+        return 'http://example.com/cb'
+
+    def get_type(self):
+        return ClientType.CONFIDENTIAL
+
 
 class AccessToken(IAccessToken):
 
@@ -154,6 +161,8 @@ class Request(message.Request):
 
     grant_type = message.Parameter(str, required=True,
                                    default='test', editable=False)
+    response_type = message.Parameter(str)
+    response_mode = message.Parameter(str)
 
     def handle(self, provider, owner):
         return self.response(self)
